@@ -557,7 +557,7 @@ class ModelPredictiveControl:
         for _ in tqdm(range(num_iter), desc="MPC Progress", disable=(not verbose)):
             control = self.get_action()
 
-            _, _, done, _ = self.microgrid.run(control, normalized=False)
+            _, _, done, _ = self.microgrid.step(control, normalized=False)
 
             if done:
                 break
@@ -906,9 +906,9 @@ class ModelPredictiveControl:
                     f"Flattening to the difference, leading to a {'import' if grid_diff > 0 else 'export'} of {grid_diff}.")
 
         if "grid" in self.microgrid_module_names.keys():
-            control[self.microgrid_module_names["grid"]] = [grid_diff]
+            control[self.microgrid_module_names["grid"]] = [np.array([grid_diff])]
 
-        control[self.microgrid_module_names["battery"]] = [battery_diff]
+        control[self.microgrid_module_names["battery"]] = [np.array([battery_diff])]
 
         return control
 
