@@ -1,12 +1,13 @@
 import numpy as np
 import pandas as pd
 
+from collections import OrderedDict
 from gym import Env
 from gym.spaces import Box, Dict, Tuple, flatten_space, flatten
 from abc import abstractmethod
 
 from pymgrid import NonModularMicrogrid, Microgrid
-from pymgrid.envs.base.skip_init import skip_init
+from pymgrid.errors.env_signature import environment_signature_error
 
 
 class BaseMicrogridEnv(Microgrid, Env):
@@ -69,26 +70,6 @@ class BaseMicrogridEnv(Microgrid, Env):
     observation_space = None
     'Space object corresponding to valid observations.'
 
-    def __new__(cls, modules, *args, **kwargs):
-        if isinstance(modules, (NonModularMicrogrid, Microgrid)):
-            import warnings
-            warnings.warn('Initializing an environment with a microgrid will be deprecated in a future version.'
-                          'Use from_microgrid() instead.', category=FutureWarning)
-
-            instance = cls.from_microgrid(modules, **kwargs)
-
-        elif isinstance(modules, int):
-            import warnings
-            warnings.warn('Initializing an environment with a scenario integer will be deprecated in a future version.'
-                          'Use from_scenario() instead.', category=FutureWarning)
-            instance = cls.from_scenario(modules, **kwargs)
-
-        else:
-            return super().__new__(cls)
-
-        cls.__init__ = skip_init(cls, cls.__init__)
-        return instance
-
     def __init__(self,
                  modules,
                  add_unbalanced_module=True,
@@ -102,6 +83,9 @@ class BaseMicrogridEnv(Microgrid, Env):
                  reset_callback=None
                  ):
 
+        if isinstance(modules, (NonModularMicrogrid, Microgrid, int)):
+            environment_signature_error(self.__class__.__name__, modules)
+
         super().__init__(modules,
                          add_unbalanced_module=add_unbalanced_module,
                          loss_load_cost=loss_load_cost,
@@ -124,13 +108,21 @@ class BaseMicrogridEnv(Microgrid, Env):
         if isinstance(keys, str):
             keys = [keys]
 
+        keys = np.array(keys)
+
         possible_keys = self.potential_observation_keys()
         bad_keys = [key for key in keys if key not in possible_keys]
 
         if bad_keys:
             raise NameError(f'Keys {bad_keys} not found in state.')
 
-        return keys
+        # Put net load at the beginning, to match where it will be in the action space
+        net_load_pos = np.where(np.array(keys) == 'net_load')[0]
+
+        if net_load_pos.size:
+            keys[[0, net_load_pos.item()]] = keys[[net_load_pos.item(), 0]]
+
+        return keys.tolist()
 
     @abstractmethod
     def _get_action_space(self, remove_redundant_actions=False):
@@ -141,38 +133,38 @@ class BaseMicrogridEnv(Microgrid, Env):
 
         state_series = self.state_series()
 
+        observation_keys = self.observation_keys or state_series.index.get_level_values(-1)
+
+        if 'net_load' in observation_keys:
+            obs_space['general'] = Tuple([Box(low=-np.inf, high=1, shape=(1, ), dtype=np.float64)])
+
         for name, module_list in self.modules.iterdict():
             tup = []
             for module_num, module in enumerate(module_list):
                 normalized_space = module.observation_space['normalized']
 
-                if not self.observation_keys:
-                    tup.append(normalized_space)
-                else:
-                    try:
-                        relevant_state_idx = state_series.loc[pd.IndexSlice[name, module_num]].index
-                    except KeyError:
-                        continue
+                try:
+                    relevant_state_idx = state_series.loc[pd.IndexSlice[name, module_num]].index
+                except KeyError:
+                    continue
 
-                    locs = [
-                        relevant_state_idx.get_loc(key) for key in self.observation_keys if key in relevant_state_idx
-                    ]
-                    if locs:
-                        box_slice = Box(
-                            normalized_space.low[locs],
-                            normalized_space.high[locs],
-                            shape=(len(locs), ),
-                            dtype=normalized_space.dtype
-                        )
+                locs = [
+                    relevant_state_idx.get_loc(key) for key in observation_keys if key in relevant_state_idx
+                ]
+                if locs:
+                    box_slice = Box(
+                        normalized_space.low[locs],
+                        normalized_space.high[locs],
+                        shape=(len(locs), ),
+                        dtype=normalized_space.dtype
+                    )
 
-                        tup.append(box_slice)
+                    tup.append(box_slice)
             if tup:
                 obs_space[name] = Tuple(tup)
 
-        if self.observation_keys and 'net_load' in self.observation_keys:
-            obs_space['net_load'] = Tuple([Box(low=-np.inf, high=1, shape=(1, ), dtype=np.float64)])
-
-        obs_space = Dict(obs_space)
+        # Prevent sorting of keys; first cast to OrderedDict
+        obs_space = Dict(OrderedDict(obs_space))
 
         return (flatten_space(obs_space) if self._flat_spaces else obs_space), obs_space
 
@@ -180,11 +172,9 @@ class BaseMicrogridEnv(Microgrid, Env):
         return self.state_series().index.get_level_values(-1).unique()
 
     def reset(self):
-        obs = super().reset()
-        obs.pop('balance')
-        obs.pop('other')
+        super().reset()
         self.reset_callback()
-        return self._get_obs(obs)
+        return self._get_obs()
 
     def step(self, action, normalized=True):
         """
@@ -221,11 +211,14 @@ class BaseMicrogridEnv(Microgrid, Env):
             Additional information from this step.
 
         """
+        self._microgrid_logger.log(net_load=self.compute_net_load())
+
         action = self.convert_action(action)
         self._log_action(action, normalized)
 
-        obs, reward, done, info = self.run(action, normalized=normalized)
-        obs = self._get_obs(obs)
+        obs, reward, done, info = super().step(action, normalized=normalized)
+        obs = self._get_obs()
+
         self.step_callback(**self._get_step_callback_info(action, obs, reward, done, info))
 
         return obs, reward, done, info
@@ -267,7 +260,7 @@ class BaseMicrogridEnv(Microgrid, Env):
 
         self._microgrid_logger.log(d)
 
-    def _get_obs(self, obs):
+    def _get_obs(self):
         if self.observation_keys:
             obs = self.state_series(normalized=True).loc[pd.IndexSlice[:, :, self.observation_keys]]
 
@@ -277,7 +270,9 @@ class BaseMicrogridEnv(Microgrid, Env):
                 obs = obs.to_frame().unstack(level=1).T.droplevel(level=1, axis=1).to_dict(orient='list')
 
         elif self._flat_spaces:
-            obs = self.flatten_obs(self._nested_observation_space, obs)
+            obs = self.state_series(normalized=True).values
+        else:
+            obs = self.state_dict(normalized=True, as_run_output=True)
 
         return obs
 
@@ -311,16 +306,23 @@ class BaseMicrogridEnv(Microgrid, Env):
 
         """
 
-        if self.current_step == self.final_step:
-            return 0.0
-
         try:
             fixed_consumption = self.modules.fixed.get_attrs('max_consumption', as_pandas=False, drop_attr_names=True)
             fixed_consumption = np.sum(list(fixed_consumption.values()))
         except AttributeError:
             fixed_consumption = 0.0
+        except IndexError:
+            # Exhausted available data. Episode should be over
+            assert self.current_step == self.final_step
+            return 0.0
+
+        try:
+            flex_max_prod = [m.max_production for m in self.modules.flex.iterlist() if m.marginal_cost == 0]
+        except IndexError:
+            # Exhausted available data. Episode should be over
+            assert self.current_step == self.final_step
+            return 0.0
 
-        flex_max_prod = [m.max_production for m in self.modules.flex.iterlist() if m.marginal_cost == 0]
         flex_production = sum(flex_max_prod)
 
         net_load = fixed_consumption - flex_production
@@ -332,9 +334,7 @@ class BaseMicrogridEnv(Microgrid, Env):
 
         return net_load
 
-    def state_dict(self, normalized=False, as_run_output=False):
-        sd = super().state_dict(normalized=normalized, as_run_output=as_run_output)
-
+    def state_dict(self, normalized=False, as_run_output=False, _initial=None):
         net_load = self.compute_net_load(normalized=normalized)
 
         if as_run_output:
@@ -342,13 +342,12 @@ class BaseMicrogridEnv(Microgrid, Env):
         else:
             net_load_entry = {'net_load': net_load}
 
-        sd['general'] = [net_load_entry]
-
-        return sd
+        state_dict = {'general': [net_load_entry]}
+        return super().state_dict(normalized=normalized, as_run_output=as_run_output, _initial=state_dict)
 
     @staticmethod
     def flatten_obs(observation_space, obs):
-        return np.concatenate([flatten(observation_space[k], v) for k, v in obs.items()])
+        return np.concatenate([flatten(space, obs[k]) for k, space in observation_space.items()])
 
     @property
     def unwrapped(self):
@@ -424,4 +423,4 @@ class BaseMicrogridEnv(Microgrid, Env):
 
     @classmethod
     def load(cls, stream):
-        return cls(super().load(stream))
+        return cls.from_microgrid(super().load(stream))
