@@ -124,9 +124,10 @@ class NetLoadContinuousMicrogridEnv(BaseMicrogridEnv):
                 self._slack_module_ref = controllable_modules_dict_lists[self._slack_module].item()
                 self._slack_module = self._slack_module_ref.name
             except ValueError:
-                msg = f"Module name {self._slack_module} does not point to one controllable candidate."
+                msg = f"Module name {self._slack_module} does not point to unique controllable candidate."
             except KeyError:
-                msg = f"No module '{self._slack_module}' amongst controllable candidates {controllable_modules_dict}"
+                msg = f"No module '{self._slack_module}' amongst controllable candidates " \
+                      f"{list(controllable_modules_dict.keys())}"
 
             if msg:
                 raise NameError(msg)
@@ -134,9 +135,8 @@ class NetLoadContinuousMicrogridEnv(BaseMicrogridEnv):
     def step(self, action):
         return super().step(action, normalized=False)
 
-    def convert_action(self, action, to_microgrid=True):
+    def convert_action(self, action, to_microgrid=True, normalize=False):
         net_load = self.compute_net_load()
-        self._microgrid_logger.log(net_load=net_load)
 
         if to_microgrid:
             relative_action = unflatten(self._nested_action_space, action)
@@ -192,11 +192,19 @@ class NetLoadContinuousMicrogridEnv(BaseMicrogridEnv):
         if self._slack_module is None:
             return action
 
-        slack_action = np.ones(self._slack_module_ref.action_space.shape)
         current_prod = sum([act[-1] for act_list in action.values() for act in act_list])
         remaining_net_load = net_load - current_prod
+
+        if remaining_net_load > 0:
+            slack_action = np.ones(self._slack_module_ref.action_space.shape)
+        else:
+            # Genset off. Ignored in all other slack modules; overwritten below.
+            slack_action = np.zeros(self._slack_module_ref.action_space.shape)
+
         slack_action[-1] = remaining_net_load
 
+
+
         module_name, module_num = self._slack_module
 
         try:
@@ -238,4 +246,8 @@ def clip_module_action(action, module):
     low = -1 * module.max_consumption
     high = module.max_production
 
+    if len(action) > 1:
+        low = [*module.action_space.unnormalized.low[:-1], low]
+        high = [*module.action_space.unnormalized.high[:-1], high]
+
     return module.action_space.clip(action, low=low, high=high)
