@@ -12,6 +12,7 @@ from pymgrid.utils.eq import verbose_eq
 from pymgrid.utils.logger import ModularLogger
 from pymgrid.utils.serialize import add_numpy_pandas_representers, add_numpy_pandas_constructors, dump_data
 from pymgrid.utils.space import MicrogridSpace
+from pymgrid.utils.deprecation import deprecation_err
 
 
 class Microgrid(yaml.YAMLObject):
@@ -225,7 +226,11 @@ class Microgrid(yaml.YAMLObject):
             self._set_initial_step(initial_step, modules_only=True)
             self._set_final_step(final_step, modules_only=True)
 
+    @deprecation_err('Microgrid.step')
     def run(self, control, normalized=True):
+        pass
+
+    def step(self, control, normalized=True):
         """
 
         Run the microgrid for a single step.
@@ -321,7 +326,7 @@ class Microgrid(yaml.YAMLObject):
                     microgrid_step.append(name, *module_step)
                     energy_needed -= source_amt
 
-        provided, consumed, reward, shaped_reward = microgrid_step.balance()
+        provided, consumed, reward, shaped_reward = microgrid_step.balance(shape_reward=True)
 
         log_dict = self._get_log_dict(
             provided-controllable_fixed_provided,
@@ -494,7 +499,7 @@ class Microgrid(yaml.YAMLObject):
             if 'Length of values' in e.args[0]:
                 module_log_lengths = pd.Series([len(log_dict) for log_dict in _log_dict.values()])
 
-                msg = f"Length of module log dicts ({module_log_lengths.unique().item()}) " \
+                msg = f"Length of module log dicts ({module_log_lengths.unique()}) " \
                       f"do not match self.current_step-initial_step ({self.current_step-initial_step}). " \
                       f"Did you set a trajectory attribute " \
                       f"('initial_step', 'final_step', 'trajectory_func') without calling Microgrid.reset()?"
@@ -731,7 +736,7 @@ class Microgrid(yaml.YAMLObject):
         """
         return self._modules
 
-    def state_dict(self, normalized=False, as_run_output=False):
+    def state_dict(self, normalized=False, as_run_output=False, _initial=None):
         """
         State of the microgrid as a dict.
 
@@ -746,6 +751,8 @@ class Microgrid(yaml.YAMLObject):
             Whether to return output in the same format as the output of :meth:`Microgrid.run`.
             Inner values are numpy arrays and not dict in this case.
 
+        _initial : dict or None
+            Internal parameter, do not use.
 
         Returns
         -------
@@ -758,9 +765,12 @@ class Microgrid(yaml.YAMLObject):
                 return np.array(list(state_dict.values()))
             return state_dict
 
-        return {name: [
-            as_run_output_f(module.state_dict(normalized=normalized)) for module in modules
-        ] for name, modules in self._modules.iterdict()}
+        state_dict = _initial or dict()
+
+        for name, modules in self._modules.iterdict():
+            state_dict[name] = [as_run_output_f(module.state_dict(normalized=normalized)) for module in modules]
+
+        return state_dict
 
     @property
     def log(self):
