@@ -137,8 +137,12 @@ class BaseMicrogridModule(yaml.YAMLObject):
             this module provided to or absorbed from the microgrid.
 
         """
-
-        denormalized_action = self._action_space.denormalize(action) if normalized else action
+        if normalized:
+            denormalized_action = self._action_space.denormalize(action)
+        elif self._action_space.clip_vals:
+            denormalized_action = self._action_space.clip(action, normalized=False)
+        else:
+            denormalized_action = action
 
         try:
             denormalized_action = denormalized_action[self._energy_pos]
@@ -274,20 +278,19 @@ class BaseMicrogridModule(yaml.YAMLObject):
         return self.update(absorbed_energy, as_sink=True)
 
     def _log(self, state_dict_pre_step, provided_energy=None, absorbed_energy=None, **info):
-        _info = info.copy()
+        energy_info = dict()
 
         if self.provided_energy_name is not None:
-            _info[self.provided_energy_name] = provided_energy if provided_energy is not None else 0.0
+            energy_info[self.provided_energy_name] = provided_energy if provided_energy is not None else 0.0
         else:
             assert provided_energy is None, 'Cannot log provided_energy with NoneType provided_energy_name.'
 
         if self.absorbed_energy_name is not None:
-            _info[self.absorbed_energy_name] = absorbed_energy if absorbed_energy is not None else 0.0
+            energy_info[self.absorbed_energy_name] = absorbed_energy if absorbed_energy is not None else 0.0
         else:
             assert absorbed_energy is None, 'Cannot log absorbed_energy with NoneType absorbed_energy_name.'
 
-        _info.update(state_dict_pre_step)
-        self._logger.log(**_info)
+        self._logger.log(**info, **energy_info, **state_dict_pre_step)
 
     def _update_step(self, reset=False):
         if reset:
@@ -680,10 +683,38 @@ class BaseMicrogridModule(yaml.YAMLObject):
 
     @property
     def production_marginal_cost(self):
+        """
+        Expected marginal cost of energy production.
+
+        Cost of producing one unit of energy.
+
+        .. warning::
+            This is a scalar value, and thus will be inaccurate for modules that do not have scalar costs.
+            It is thus only an expectation.
+
+        Returns
+        -------
+        production_marginal_cost : float
+
+        """
         return 0.0
 
     @property
     def absorption_marginal_cost(self):
+        """
+        Expected marginal cost of energy absorption.
+
+        Cost of absorbing one unit of energy.
+
+        .. warning::
+            This is a scalar value, and thus will be inaccurate for modules that do not have scalar costs.
+            It is thus only an expectation.
+
+        Returns
+        -------
+        absorption_marginal_cost : float
+
+        """
         return 0.0
 
     @property
