@@ -277,15 +277,15 @@ class BaseTimeSeriesMicrogridModule(BaseMicrogridModule):
     @property
     def forecaster_increase_uncertainty(self):
         """
-        View of :class:`pymgrid.forecast.GaussianNoiseForecaster``.increase_uncertainty`.
+        View of :attr:`.GaussianNoiseForecaster.increase_uncertainty`.
 
         Required for serialization as a mirror to the class parameter.
-        Will only ever be True if ``self.forecaster`` is a ``GaussianNoiseForecaster``.
+        Will only ever be True if :attr:`.forecaster` is a :class:`.GaussianNoiseForecaster`.
 
         Returns
         -------
         forecaster_increase_uncertainty : bool
-            Associated attribute of ``self.forecaster``.
+            Associated attribute of `:attr:`.forecaster`.
 
         """
         try:
@@ -296,10 +296,10 @@ class BaseTimeSeriesMicrogridModule(BaseMicrogridModule):
     @property
     def forecaster_relative_noise(self):
         """
-        View of :class:`pymgrid.forecast.GaussianNoiseForecaster``.forecaster_relative_noise`.
+        View of :attr:`.GaussianNoiseForecaster.relative_noise`.
 
         Required for serialization as a mirror to the class parameter.
-        Will only ever be True if ``self.forecaster`` is a ``GaussianNoiseForecaster``.
+        Will only ever be True if ``self.forecaster`` is a :class:`.GaussianNoiseForecaster`.
 
         Returns
         -------
