@@ -56,6 +56,10 @@ class GridModule(BaseTimeSeriesMicrogridModule):
     cost_per_unit_co2 : float, default 0.0
         Marginal cost of grid co2 production.
 
+    normalized_action_bounds : tuple of int or float, default (0, 1).
+        Bounds of normalized actions.
+        Change to (-1, 1) for e.g. an RL policy with a Tanh output activation.
+
     raise_errors : bool, default False
         Whether to raise errors if bounds are exceeded in an action.
         If False, actions are clipped to the limit possible.
@@ -323,11 +327,11 @@ class GridModule(BaseTimeSeriesMicrogridModule):
 
     @property
     def production_marginal_cost(self):
-        return self.import_price[0]
+        return -1 * self.get_cost(1, as_source=True, as_sink=False)
 
     @property
     def absorption_marginal_cost(self):
-        return self.export_price[0]
+        return self.get_cost(1, as_source=False, as_sink=True)
 
     @property
     def is_source(self):
